@@ -1,12 +1,12 @@
 package Finance::Currency::Convert::KlikBCA;
 
-our $DATE = '2015-07-10'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 use LWP::Simple;
 use Parse::Number::ID qw(parse_number_id);
 
@@ -163,7 +163,7 @@ Finance::Currency::Convert::KlikBCA - Convert currency using KlikBCA
 
 =head1 VERSION
 
-This document describes version 0.08 of Finance::Currency::Convert::KlikBCA (from Perl distribution Finance-Currency-Convert-KlikBCA), released on 2015-07-10.
+This document describes version 0.09 of Finance::Currency::Convert::KlikBCA (from Perl distribution Finance-Currency-Convert-KlikBCA), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -194,7 +194,7 @@ if you need the more complete result.
 
 =head2 convert_currency($n, $from, $to) -> any
 
-Convert currency using KlikBCA.
+{en_US Convert currency using KlikBCA}.
 
 Arguments ('*' denotes required arguments):
 
@@ -213,7 +213,7 @@ Return value:  (any)
 
 =head2 get_currencies() -> [status, msg, result, meta]
 
-Extract data from KlikBCA/BCA page.
+{en_US Extract data from KlikBCA/BCA page}.
 
 No arguments.
 
@@ -238,7 +238,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Finance-Cu
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Finance-Currency-Convert-KlikBCA>.
+Source repository is at L<https://github.com/sharyanto/perl-Finance-Currency-Convert-KlikBCA>.
 
 =head1 BUGS
 
